# PreviousCreatedTime

The earliest created time on the current page. A value of \"\" is the start of the first page. This is typically combined with other pagination parameters to sub-paginate data that has too many results for the primary pagination key. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


